@@ -137,10 +137,10 @@ class RinnaiWaterHeater(object):
 
     def refreshToken(self, accessToken):
         payload = ("{\"ClientId\":\"%s\",\"AuthFlow\":\"REFRESH_TOKEN_AUTH\",\"AuthParameters\":"
-                   "\"REFRESH_TOKEN\":\"%s\"}}" % (self.client_id, token['refresh_token']))
+                   "\"REFRESH_TOKEN\":\"%s\"}}" % (self.client_id, accessToken['refresh_token']))
 
         r = requests.post(
-            baseAuthUrl,
+            BASE_AUTH_URL,
             data=payload,
             headers=initAuthHeaders,
         )
@@ -241,3 +241,18 @@ class RinnaiWaterHeater(object):
                 "{\"USERNAME\":\"%s\",\"PASSWORD_CLAIM_SECRET_BLOCK\":\"%s\",\"TIMESTAMP\":\"%s\","
                 "\"PASSWORD_CLAIM_SIGNATURE\":\"%s\"},\"ClientMetadata\":{}}" 
                 % (self.client_id,user_id_for_srp,secret_block_b64,timestamp,signature_string.decode('utf-8')))
+
+    def set_temp(self, device_id: str, user_uuid: str, temp: int):
+        url = "https://d1coipyopavzuf.cloudfront.net/api/device_shadow/input"
+        
+        # check if the temp is a multiple of 5. Rinnai only takes temps this way
+        if temp % 5 == 0:
+            payload="user=%s&thing=%s&attribute=set_domestic_temperature&value=%s" % (user_uuid, device_id, temp)
+            headers = {
+                'Content-Type': 'application/x-www-form-urlencoded'
+            }
+            r = requests.post(
+                url,
+                data=payload,
+                headers=headers,
+            )
